.. dtest documentation master file, created by
   sphinx-quickstart on Wed Nov 24 08:17:04 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Moneyflow Base utils
====================

.. note::
   This project is under development


.. toctree::
   mbase/services.rst
   mbase/eventlog.rst
   mbase/utils.rst
   :maxdepth: 2
   :caption: MBase:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
